<?php
// guvenlik kodlarini dahil et
require_once 'inc/guvenlik.php';

// Fetch all uploaded files from the database
$sql = "SELECT * FROM uploads";
$stmt = $baglantim->query($sql);
$files = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Handle file deletion
if (isset($_GET['delete'])) {
    // Güvenli ID kontrolü
    $fileId = intval($_GET['delete']);

    // Fetch file information to delete from the server
    $sql = "SELECT * FROM uploads WHERE id = ?";
    $stmt = $baglantim->prepare($sql);
    $stmt->execute([$fileId]);
    $file = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($file) {
        $filePath = $file['file_path'];

        // Delete file from the server if exists
        if (file_exists($filePath)) {
            // Silme işlemi başarısız olursa hata mesajı eklenebilir
            if (!unlink($filePath)) {
                $_SESSION['message'] = 'Dosya sunucudan silinirken bir hata oluştu!';
                header("Location: delete_files.php");
                exit();
            }
        }

        // Delete file record from the database
        $sql = "DELETE FROM uploads WHERE id = ?";
        $stmt = $baglantim->prepare($sql);
        $stmt->execute([$fileId]);

        // Success message for deletion
        $_SESSION['message'] = 'Dosya başarıyla silindi!';
        header("Location: delete_files.php");
        exit();
    } else {
        // File not found case
        $_SESSION['message'] = 'Silinecek dosya bulunamadı!';
        header("Location: delete_files.php");
        exit();
    }
}

?>



<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Delete Files</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@4.6.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        .file-preview {
            display: inline-block;
            margin: 10px;
            width: 120px;
            height: 120px;
            text-align: center;
            background-color: #f1f1f1;
            padding: 10px;
            border-radius: 8px;
            position: relative;
            overflow: hidden;
        }

        .file-preview img,
        .file-preview i {
            width: 80px;
            height: 80px;
            object-fit: cover;
            margin-bottom: 8px;
        }

        .delete-btn {
            position: absolute;
            top: 5px;
            right: 5px;
            background: rgba(255, 0, 0, 0.6);
            border: none;
            padding: 4px;
            border-radius: 50%;
            color: white;
            font-size: 12px;
            cursor: pointer;
        }

        .delete-btn:hover {
            background-color: rgba(255, 0, 0, 1);
        }
    </style>
</head>
<body>

<div class="container mt-5">
    <h2>Manage Uploaded Files</h2>
    <div class="row">
        <?php foreach ($files as $file): ?>
            <div class="file-preview">
                <?php if (strpos($file['file_type'], 'image') !== false): ?>
                    <img src="<?php echo $file['file_path']; ?>" alt="file preview">
                <?php elseif ($file['file_type'] == 'application/pdf'): ?>
                    <i class="fas fa-file-pdf" style="font-size: 40px; color: #dc3545;"></i>
                <?php else: ?>
                    <i class="fas fa-file-alt" style="font-size: 40px; color: #007bff;"></i>
                <?php endif; ?>

                <div class="file-name"><?php echo htmlspecialchars($file['file_name']); ?></div>
                <div class="file-size"><?php echo round($file['file_size'] / 1024 / 1024, 2) . ' MB'; ?></div>

                <!-- Delete button -->
                <a href="?delete=<?php echo $file['id']; ?>" class="delete-btn" onclick="return confirm('Are you sure you want to delete this file?');">
                    <i class="fas fa-times"></i>
                </a>
            </div>
        <?php endforeach; ?>
    </div>
</div>

<script src="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/js/all.min.js"></script>
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
</body>
</html>
