<?php
// Güvenlik başlıkları
header('X-Frame-Options: SAMEORIGIN');
header('Strict-Transport-Security: max-age=31536000; includeSubDomains');
header('X-XSS-Protection: 1; mode=block');
header('X-Content-Type-Options: nosniff');

// Çıktı tamponlamayı aç (header hatasını önlemek için)
ob_start();

// Oturumu başlat (Eğer zaten başlamamışsa)
if (session_status() == PHP_SESSION_NONE) {
    session_start();
}

// Oturum kontrolü ve referer kontrolü
if (!isset($_SESSION['eposta'])) {
    header("Location: giris.php"); // Yönlendirme
    exit;
}

// Referer kontrolü (Yalnızca geçerli sayfalardan gelen istekleri kabul et)
$$valid_referers = ['localhost/komponent']; // İzin verilen referer adreslerini buraya ekleyin
$referer = parse_url($_SERVER['HTTP_REFERER'], PHP_URL_HOST);
if (!in_array($referer, $valid_referers)) {
    die("Geçersiz referer.");
}

// Veritabanı bağlantısını dahil et
require_once 'inc/baglan.php';

$files = []; // Başlangıçta boş bir dizi

// Komponent tablosundaki dosya ID'lerini al
try {
    $sql = "SELECT * FROM komponent WHERE id = ?";
    $stmt = $baglantim->prepare($sql);
    $stmt->execute([347]); // Örnek olarak komponent id'si 347
    $komponent = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($komponent) {
        // Dosya ID'lerini virgülle ayır
        $dosyaIds = explode(',', $komponent['dosyalar']);

        // Dosya ID'lerinin sadece sayısal değerler içerdiğinden emin olun
        $dosyaIds = array_filter($dosyaIds, function($id) {
            return is_numeric($id);
        });

        // Eşleşen dosyaları uploads tablosundan al
        if (count($dosyaIds) > 0) {
            $inQuery = implode(',', array_fill(0, count($dosyaIds), '?'));
            $sql = "SELECT * FROM uploads WHERE id IN ($inQuery)";
            $stmt = $baglantim->prepare($sql);
            $stmt->execute($dosyaIds);
            $files = $stmt->fetchAll(PDO::FETCH_ASSOC);
        }
    }

} catch (PDOException $e) {
    // Veritabanı hatası durumunda düzgün bir hata mesajı
    echo "Veritabanı hatası: " . htmlspecialchars($e->getMessage()); // Hata mesajı güvenli şekilde çıktı verildi
}

ob_end_flush();
?>


<h6>TEST SAYFASI TUM ISLEVLER CALIZMAZ</h6>

    <style>
        .file-preview-container {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(200px, 1fr));
            gap: 30px;
            padding-top: 30px;
        }
        .file-preview {
            background-color: #fff;
            border-radius: 10px;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
            text-align: center;
            padding: 20px;
        }
        .file-preview img, .file-preview i {
            width: 100%;
            height: 180px;
            object-fit: cover;
            border-radius: 8px;
        }
        .file-name {
            font-size: 14px;
            margin-top: 10px;
        }
    </style>
    <h1 class="text-center my-5">Dosya Eşleşme Sonuçları</h1>

<div class="file-preview-container">
    <?php if (!empty($files)): ?>
        <?php foreach ($files as $file): ?>
            <div class="file-preview">
                <!-- Dosya önizleme -->
                <?php
                $fileExtension = strtolower(pathinfo($file['file_name'], PATHINFO_EXTENSION));
                // Dosya türüne göre önizleme
                if (in_array($fileExtension, ['jpg', 'jpeg', 'png', 'gif', 'webp'])) {
                    // Gerçek dosya türünü kontrol et
                    $imageInfo = getimagesize($file['file_path']);
                    if ($imageInfo !== false) {
                        echo '<img src="' . htmlspecialchars($file['file_path']) . '" alt="file preview">';
                    } else {
                        echo '<i class="fas fa-file-image" style="font-size: 100px; color: #95a5a6;"></i>';
                    }
                } elseif ($fileExtension == 'pdf') {
                    echo '<i class="fas fa-file-pdf" style="font-size: 100px; color: #e74c3c;"></i>';
                } elseif (in_array($fileExtension, ['docx', 'doc'])) {
                    echo '<i class="fas fa-file-word" style="font-size: 100px; color: #3498db;"></i>';
                } elseif (in_array($fileExtension, ['xlsx', 'xls'])) {
                    echo '<i class="fas fa-file-excel" style="font-size: 100px; color: #2ecc71;"></i>';
                } elseif (in_array($fileExtension, ['zip', 'rar'])) {
                    echo '<i class="fas fa-file-archive" style="font-size: 100px; color: #f39c12;"></i>';
                } else {
                    echo '<i class="fas fa-file" style="font-size: 100px; color: #95a5a6;"></i>';
                }
                ?>
                <div class="file-name"><?php echo htmlspecialchars($file['file_name']); ?></div>
            </div>
        <?php endforeach; ?>
    <?php else: ?>
        <p class="text-center">Eşleşen dosya bulunamadı.</p>
    <?php endif; ?>
</div>