<?php
// Güvenlik başlıkları
header('X-Frame-Options: SAMEORIGIN');
header('Strict-Transport-Security: max-age=31536000; includeSubDomains');
header('X-XSS-Protection: 1; mode=block');
header('X-Content-Type-Options: nosniff');

// Oturum kontrolü
session_start();
if (session_status() == PHP_SESSION_NONE) {
    session_start(); // Oturum başlat
}

// CSRF token oluşturulması (form gönderiminden önce)
if (empty($_SESSION['csrf_token'])) {
    $_SESSION['csrf_token'] = bin2hex(random_bytes(32)); // Güvenli bir token üret
}

// CSRF token kontrolü (formdan gelen token ile karşılaştır)
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    if (!isset($_POST['csrf_token']) || $_POST['csrf_token'] !== $_SESSION['csrf_token']) {
        die("CSRF attack detected!"); // Token uyumsuzluğu durumunda işlem durdurulacak
    }
}

// Oturum kontrolü ve referer kontrolü
if (!isset($_SESSION['eposta'])) {
    header("Location: giris.php"); // Yönlendirme
    exit;
}

// Referer kontrolü (Yalnızca geçerli sayfalardan gelen istekleri kabul et)
$valid_referers = ['localhost/komponent']; // İzin verilen referer adreslerini buraya ekleyin
$referer = parse_url($_SERVER['HTTP_REFERER'], PHP_URL_HOST);
if (!in_array($referer, $valid_referers)) {
    die("Geçersiz referer.");
}

// Veritabanı bağlantısını dahil et
require_once 'inc/baglan.php';

// Tekil dosya silme işlemi
if (isset($_POST['delete_id'])) {
    $fileId = (int) $_POST['delete_id']; // Güvenli id alımı

    // Dosya bilgilerini güvenli şekilde çekiyoruz
    $sql = "SELECT * FROM uploads WHERE id = ?";
    $stmt = $baglantim->prepare($sql);
    $stmt->execute([$fileId]);
    $file = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($file) {
        $filePath = $file['file_path'];

        // Dosyanın sunucuda mevcut olup olmadığını kontrol et
        if (file_exists($filePath)) {
            if (!unlink($filePath)) {
                $_SESSION['success'] = 'Dosya silinirken hata oluştu!';
                header("Location: list_files.php");
                exit();
            }
        }

        // Veritabanından dosyayı sil
        $sql = "DELETE FROM uploads WHERE id = ?";
        $stmt = $baglantim->prepare($sql);
        if ($stmt->execute([$fileId])) {
            $_SESSION['success'] = 'Dosya başarıyla silindi!';
        } else {
            $_SESSION['success'] = 'Veritabanında hata oluştu!';
        }
    } else {
        $_SESSION['success'] = 'Dosya bulunamadı!';
    }

    // Dosya silindikten sonra geri yönlendir
    header("Location: list_files.php");
    exit();
}

// Toplu dosya silme işlemi
if (isset($_POST['delete_selected'])) {
    if (!empty($_POST['file_ids'])) {
        foreach ($_POST['file_ids'] as $fileId) {
            $fileId = (int) $fileId; // Güvenli id alımı

            // Dosya bilgilerini güvenli şekilde çekiyoruz
            $sql = "SELECT * FROM uploads WHERE id = ?";
            $stmt = $baglantim->prepare($sql);
            $stmt->execute([$fileId]);
            $file = $stmt->fetch(PDO::FETCH_ASSOC);

            if ($file) {
                $filePath = $file['file_path'];

                // Dosyanın mevcut olup olmadığını kontrol et ve sil
                if (file_exists($filePath)) {
                    if (!unlink($filePath)) {
                        $_SESSION['success'] = 'Bazı dosyalar silinirken hata oluştu!';
                        header("Location: index.php?sayfa=DosyaListesi");
                        exit();
                    }
                }

                // Dosya kaydını veritabanından sil
                $sql = "DELETE FROM uploads WHERE id = ?";
                $stmt = $baglantim->prepare($sql);
                $stmt->execute([$fileId]);
            }
        }

        // Başarı mesajını oturumda sakla
        $_SESSION['success'] = 'Seçilen dosyalar başarıyla silindi!';

        // Toplu silme işlemi sonrasında geri yönlendir
        header("Location: index.php?sayfa=DosyaListesi");
        exit();
    } else {
        // Hiçbir dosya seçilmemişse hata mesajı göster
        $_SESSION['success'] = 'Dosya seçilmedi!';
        header("Location: index.php?sayfa=DosyaListesi");
        exit();
    }
}
?>
