<?php
session_start();
ob_start(); // Çıktı tamponlamayı başlatıyoruz, header hatalarını engellemek için.

// Güvenlik başlıkları
@header('X-Frame-Options: SAMEORIGIN');
@header('Strict-Transport-Security: max-age=31536000; includeSubDomains');
@header('X-XSS-Protection: 1; mode=block');
@header('X-Content-Type-Options: nosniff');

// Form verilerinin kontrolü
if (isset($_SERVER['HTTP_REFERER']) && isset($_POST['eposta']) && isset($_POST['parola'])) {
    include_once 'inc/baglan.php';

    $epostam = trim($_POST['eposta']);
    $parolam = trim($_POST['parola']);

    // SQL sorgusuna hazırlık (Prepared Statements ile SQL Injection'dan korunmuş)
    $veritabani = "SELECT * FROM uye WHERE eposta = :eposta AND aktif = 1";
    $sorgu = $baglantim->prepare($veritabani);
    $sorgu->bindParam(':eposta', $epostam, PDO::PARAM_STR);
    $sorgu->execute();
    $sonuc = $sorgu->fetchAll(PDO::FETCH_OBJ);

    if ($sorgu->rowCount() > 0) {
        // Parola doğrulama (password_verify ile güvenli doğrulama)
        if (password_verify($parolam, $sonuc[0]->parola)) {
            // Başarılı giriş sonrası oturum başlat
            session_regenerate_id(true); // Session Fixation saldırılarına karşı güvenlik

            $_SESSION['eposta'] = $epostam;

            // Hatırlama işlemi
            if (isset($_POST['hatirla'])) {
                setcookie('postam', $epostam, time() + (365 * 24 * 60 * 60) * 3, '/', '', isset($_SERVER['HTTPS']), true);
                setcookie('parolam', $parolam, time() + (365 * 24 * 60 * 60) * 3, '/', '', isset($_SERVER['HTTPS']), true);
            } else {
                // Cookie'yi silme
                setcookie('postam', '', time() - 3600, '/');
                setcookie('parolam', '', time() - 3600, '/');
            }

            echo 'true'; // Başarılı giriş
        } else {
            echo 'false'; // Yanlış parola
        }
    } else {
        echo 'false'; // Kullanıcı bulunamadı
    }

} else {
    // Hatalı erişim durumu
    @header('Location: index.php');
    exit;
}

ob_end_flush(); // Çıktı tamponlamayı bitir.
?>