<?php
// Çıktı tamponlamayı aç (header hatasını önlemek için)
ob_start(); // Bu satırı ekledik

// Güvenlik başlıkları
@header('X-Frame-Options: SAMEORIGIN');
@header('Strict-Transport-Security: max-age=31536000; includeSubDomains');
@header('X-XSS-Protection: 1; mode=block');
@header('X-Content-Type-Options: nosniff');

// Oturum başlat
session_start();

// Eğer oturumda 'eposta' yoksa giriş sayfasına yönlendir
if (!isset($_SESSION['eposta'])) {
    ?>
    <!DOCTYPE html>
    <html lang="tr">
    <head>
        <meta charset="utf-8">
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <title> Giriş Yap </title>
        <script src="https://code.jquery.com/jquery-3.7.1.js"></script>
        <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet">
        <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.7.2/css/all.min.css">
    </head>
    <body>
    <!-- Giriş formu -->
    <div id="giris_formu" class="container col-sm-6 p-5">
        <div class="form-control">
            <h4 class="text-center mb-4">Giriş Yap</h4>
            <div class="alert" id="hata-mesaji" style="display: none;"></div>
            <form id="GirisYap" class="login-form form-control was-validated" action="giris-yapiliyor.php">
                <div id="eposta1" class="form-outline mb-4">
                    <label class="form-label" for="eposta">E-Posta</label>
                    <input type="email" id="eposta" name="eposta"
                           value="<?= isset($_COOKIE['postam']) ? $_COOKIE['postam'] : '' ?>" class="form-control"
                           required="">
                    <div class="valid-feedback">Geçerli</div>
                    <div class="invalid-feedback">Lütfen kontrol edin</div>
                </div>
                <div id="parola1" class="form-outline mb-4">
                    <label class="form-label" for="parola">Parola</label>
                    <input type="password" id="parola" name="parola"
                           value="<?= isset($_COOKIE['parolam']) ? $_COOKIE['parolam'] : '' ?>" class="form-control"
                           minlength="6" required="">
                    <div class="valid-feedback">Geçerli</div>
                    <div class="invalid-feedback">Lütfen kontrol edin</div>
                </div>
                <div class="row mb-4">
                    <div class="col d-flex justify-content-center">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="hatirla"
                                   id="hatirla" <?php if (isset($_COOKIE["postam"])) { ?> checked <?php } ?> autocomplete='off'>
                            <label class="form-check-label" for="hatirla"> Beni Hatırla </label>
                        </div>
                    </div>
                    <div class="col">
                        <a href="#!" class="text-decoration-none" data-bs-toggle="modal" data-bs-target="#parolaModal">Parolamı Unuttum?</a>
                    </div>
                </div>
                <button type="submit" id="girisButon" name="girisButon" class="btn btn-primary btn-block mb-4"
                        style="width: 100%;">Giriş Yap
                </button>
            </form>
            <div class="text-center">
                <p>Üye Değilmisin? <a href="#!" class="text-decoration-none">Üye Ol</a></p>
            </div>
        </div>
    </div>

    <!-- Parola Sıfırlama Modal -->
    <div class="modal fade" id="parolaModal" tabindex="-1" aria-labelledby="parolaModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="parolaModalLabel">Parola Sıfırlama</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <form id="parolaSifirlaForm">
                        <div class="mb-3">
                            <label for="epostaSifirla" class="form-label">E-Posta Adresiniz</label>
                            <input type="email" class="form-control" id="epostaSifirla" name="epostaSifirla" required>
                        </div>
                        <button type="submit" class="btn btn-primary">Şifreyi Sıfırla</button>
                    </form>
                    <div id="sifirlamaMesaj" class="mt-3" style="display: none;"></div>
                </div>
            </div>
        </div>
    </div>
    <script src="js/script.js"></script> <!-- jquery kodlarimizi cekelim -->
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/js/bootstrap.min.js"></script>

    <script>
        $(document).ready(function() {
            $('#parolaSifirlaForm').on('submit', function(e) {
                e.preventDefault();

                var eposta = $('#epostaSifirla').val();

                // AJAX ile parola sıfırlama işlemi
                $.ajax({
                    url: 'parola-sifirla.php', // İşlem yapılacak PHP dosyası
                    method: 'POST',
                    data: { eposta: eposta },
                    success: function(response) {
                        $('#sifirlamaMesaj').show().html(response);
                    },
                    error: function() {
                        $('#sifirlamaMesaj').show().html('<div class="alert alert-danger">Bir hata oluştu. Lütfen tekrar deneyin.</div>');
                    }
                });
            });
        });
    </script>
    </body>
    </html>

    <?php
} else {
    // Eğer oturum açılmışsa, index.php'ye yönlendir
    header("Location: index.php");
    exit;  // Çıkış komutunu eklemeyi unutma
}

// Çıktı tamponlamayı bitir
ob_end_flush();
?>