<?php
require_once 'inc/guvenlik.php';

$errors = [];
$data = [];

// Veriyi kontrol etme
if (empty($_POST['tedarikciEkleAd'])) {
    $errors['tedarikciEkleAd'] = 'Zorunlu alan';
}

// Eğer herhangi bir hata varsa, hatayı dön
if (!empty($errors)) {
    $data['success'] = false;
    $data['errors'] = $errors;
} else {
    $data['success'] = true;
    $data['message'] = 'Eklendi!';

    // Veriyi al ve temizle
    $ad = trim($_POST['tedarikciEkleAd']);
    $ad = htmlspecialchars($ad, ENT_QUOTES, 'UTF-8'); // XSS saldırılarına karşı önlem

    // Prepared statement ile güvenli sorgu
    $kategori_ekle_sql = "INSERT INTO tedarikci (ad) VALUES (:ad)";
    $kategori_ekle = $baglantim->prepare($kategori_ekle_sql);

    // Parametreli sorgu kullanarak veriyi ekleme
    $kategori_ekle->bindParam(':ad', $ad, PDO::PARAM_STR);

    try {
        $kategori_ekle->execute();

        // Veri başarıyla eklenirse
        if ($kategori_ekle->rowCount() > 0) {
            $data['success'] = true;
            $data['message'] = 'Veritabanına Eklendi!';
        } else {
            $data['success'] = false;
            $data['message'] = 'Veri eklenirken bir hata oluştu!';
        }
    } catch (PDOException $e) {
        // Veritabanı hatalarını yakala
        $data['success'] = false;
        $data['message'] = 'Veritabanı hatası: ' . $e->getMessage();
    }
}

// JSON formatında sonucu döndür
echo json_encode($data);
?>