<?php
// guvenlik kodlarini dahil et
require_once 'inc/guvenlik.php';

// Kabul edilen dosya türlerini ve maksimum dosya boyutunu tanımla
$acceptedTypes = ['image/jpeg', 'image/png', 'image/gif', 'image/webp', 'application/pdf'];
$maxFileSize = 40 * 1024 * 1024; // 40MB (bayt cinsinden)

// Dosyaların yükleneceği dizin
$uploadDir = 'uploads/';

// Yükleme dizini mevcut değilse oluştur
if (!is_dir($uploadDir)) {
    mkdir($uploadDir, 0777, true);
}

// Dosyaların yükleneceğini kontrol et
if (isset($_FILES['files'])) {
    $files = $_FILES['files'];
    $uploadedFiles = [];

    // Her bir dosyayı işle
    foreach ($files['tmp_name'] as $key => $tmp_name) {
        $fileName = $files['name'][$key];
        $fileTmpName = $files['tmp_name'][$key];
        $fileType = $files['type'][$key];
        $fileSize = $files['size'][$key];

        // Dosya türünün kabul edilen türlerden biri olup olmadığını kontrol et
        if (!in_array($fileType, $acceptedTypes)) {
            echo "Dosya türü '$fileType' kabul edilmedi. Sadece JPEG, PNG, GIF, WEBP, PDF dosyalarına izin verilmektedir.<br>";
            continue;
        }

        // Dosya boyutunun limitin üzerinde olup olmadığını kontrol et
        if ($fileSize > $maxFileSize) {
            echo "Dosya '$fileName' maksimum 40MB boyut limitini aşıyor.<br>";
            continue;
        }

        // Dosya adını güvenli hale getirmek için Türkçe karakterleri ve boşlukları değiştirelim
        $safeFileName = strtoupper(strtr($fileName, [
            'ç' => 'c', 'ğ' => 'g', 'ı' => 'i', 'ö' => 'o', 'ş' => 's', 'ü' => 'u',
            'Ç' => 'C', 'Ğ' => 'G', 'İ' => 'I', 'Ö' => 'O', 'Ş' => 'S', 'Ü' => 'U'
        ]));  // Türkçe karakterleri İngilizce karşılıklarıyla değiştir
        $safeFileName = preg_replace('/\s+/', '-', $safeFileName);  // Boşlukları "-" ile değiştir
        $fileDestination = $uploadDir . $safeFileName;

        // Dosyanın zaten mevcut olup olmadığını kontrol et
        if (file_exists($fileDestination)) {
            echo "Dosya '$safeFileName' zaten mevcut. Lütfen farklı bir dosya seçin.<br>";
            continue;
        }

        // Yüklenen dosyayı hedef dizine taşı
        if (move_uploaded_file($fileTmpName, $fileDestination)) {
            // Veritabanına dosya bilgilerini ekle
            try {
                $stmt = $baglantim->prepare("INSERT INTO uploads (file_name, file_type, file_size, file_path) VALUES (?, ?, ?, ?)");
                $stmt->execute([$safeFileName, $fileType, $fileSize, $fileDestination]);

                $uploadedFiles[] = $safeFileName;  // Başarıyla yüklenen dosya adlarını kaydet
            } catch (PDOException $e) {
                echo "Veritabanı hatası: " . htmlspecialchars($e->getMessage());
                continue;
            }
        } else {
            echo "Dosya '$safeFileName' yükleme dizinine taşınırken hata oluştu.<br>";
        }
    }

    // Başarıyla yüklenen dosyaların adlarını geri dön
    if (!empty($uploadedFiles)) {
        echo "Dosyalar başarıyla yüklendi: " . implode(', ', $uploadedFiles);
    } else {
        echo "Hiç dosya yüklenmedi.";
    }
} else {
    echo "Hiç dosya seçilmedi.";
}

// Veritabanı bağlantısını kapat
$baglantim = null;

// Çıktı tamponlamayı kapat
ob_end_flush();
?>
